@@ -1,21 +1,22 @@
-from missingpy import KNNImputer
 import os
+
 import pandas as pd
+from missingpy import KNNImputer
 from sklearn.preprocessing import StandardScaler
 
 from .base import DATA_DIR
 
 
 def clean_dragon(save=False):
-    source = os.path.join(DATA_DIR, 'cids-smiles-dragon.txt')
-    df = pd.read_csv(source).set_index('CID')
+    source = os.path.join(DATA_DIR, "cids-smiles-dragon.txt")
+    df = pd.read_csv(source).set_index("CID")
     df = df.iloc[:, 1:]  # Drop SMILES column
 
     # Scale to mean 0, variance 1
     ss = StandardScaler()
     good = df.columns[df.isnull().sum() < 500]
     df = df[good]
-    scaled = ss.fit_transform(df.astype('float'))
+    scaled = ss.fit_transform(df.astype("float"))
     df = pd.DataFrame(scaled, index=df.index, columns=df.columns)
 
     # Impute missing values
@@ -25,7 +26,7 @@ def clean_dragon(save=False):
 
     # Optionally save to disk
     if save:
-        dest = os.path.join(DATA_DIR, 'cids-smiles-dragon-scaled-imputed.txt')
+        dest = os.path.join(DATA_DIR, "cids-smiles-dragon-scaled-imputed.txt")
         df.to_csv(dest)
 
     return df
